@@ -44,6 +44,8 @@ namespace MediaConch
         void set_implementation_schema_file(const std::string& file);
         void set_implementation_verbosity(const std::string& verbosity);
         int  set_policy_reference_file(const std::string& file);
+        void set_policy_verbosity(const std::string& verbosity);
+        void set_full_report(bool full);
         int  add_plugin_to_use(const std::string& plugin);
         int  set_user_to_use(const std::string& user);
         int  set_compression_mode(const std::string& mode_str);
@@ -60,6 +62,7 @@ namespace MediaConch
         int  set_watch_folder_user(const std::string& user);
         void set_list_watch_folders_mode();
         void set_list_mode();
+        int  add_output(const std::string& format, const std::string& filename);
 
       private:
         CLI(const CLI&);
@@ -81,11 +84,13 @@ namespace MediaConch
         std::vector<std::string> policies;
         std::vector<std::string> plugins;
         std::vector<std::pair<std::string,std::string> > options;
+        std::vector<std::pair<MediaConchLib::format,std::string> > outputs;
         std::string              error;
         std::string              display_content;
         std::string              configuration_file;
         std::string              plugins_configuration_file;
         std::string              policy_reference_file;
+        std::string              policy_verbosity;
         std::string              watch_folder;
         std::string              watch_folder_reports;
         long                    *watch_folder_user;
@@ -97,6 +102,7 @@ namespace MediaConch
         bool                    use_daemon;
         bool                    asynchronous;
         bool                    force_analyze;
+        bool                    full_report;
         bool                    mil_analyze;
         bool                    watch_folder_recursive;
         bool                    create_policy_mode;
