@@ -88,6 +88,9 @@ public:
     virtual int ui_settings_save_last_save_display_path(const std::string&, int user_id = -1);
     virtual int ui_settings_get_last_save_display_path(std::string&, int user_id = -1);
 
+    virtual int ui_settings_save_displaycaptions_option(const std::string&, int user_id = -1);
+    virtual int ui_settings_get_displaycaptions_option(std::string&, int user_id = -1);
+
     virtual int  ui_settings_save_mco_token(const std::string&, int user_id=-1);
     virtual int  ui_settings_get_mco_token(std::string&, int user_id = -1);
 
