@@ -14,6 +14,7 @@
 #include <QFileDialog>
 #include <QTextStream>
 #include <QDesktopServices>
+#include <QRegularExpression>
 
 namespace MediaConch
 {
@@ -82,7 +83,6 @@ namespace MediaConch
             return;
 
         QTextStream out(&file);
-        out.setCodec("UTF-8");
         out << report;
     }
 
@@ -448,16 +448,22 @@ namespace MediaConch
         return ret;
     }
 
-    void WebCommonPage::on_save_settings_selected(const QString& policy,
-                                            const QString& display,
-                                            const QString& verbosity,
-                                            const QString& parsespeed,
-                                            const QString& save_report_path, const QString& load_files_path,
-                                            const QString& save_policy_path, const QString& load_policy_path,
-                                            const QString& save_display_path, const QString& load_display_path)
+    void WebCommonPage::on_save_settings_selected(const QJsonObject& values)
     {
         UiSettings& settings = mainwindow->get_settings();
 
+        const QString policy = values.value("policy").toString();
+        const QString display = values.value("display").toString();
+        const QString verbosity = values.value("verbosity").toString();
+        const QString parsespeed = values.value("parsespeed").toString();
+        const QString displaycaptions = values.value("displaycaptions").toString();
+        const QString save_report_path = values.value("save_report_path").toString();
+        const QString load_files_path = values.value("load_files_path").toString();
+        const QString save_policy_path = values.value("save_policy_path").toString();
+        const QString load_policy_path = values.value("load_policy_path").toString();
+        const QString save_display_path = values.value("save_display_path").toString();
+        const QString load_display_path = values.value("load_display_path").toString();
+
         //policy
         if (policy == "-2")
             settings.change_default_policy("last");
@@ -488,6 +494,10 @@ namespace MediaConch
         else
             settings.change_default_parsespeed(parsespeed.toStdString());
 
+        //displaycaptions
+        if (!displaycaptions.isEmpty())
+            settings.change_displaycaptions_option(displaycaptions.toStdString());
+
         //Save report path
         std::string r_s_path;
         if (save_report_path == "last")
@@ -785,34 +795,25 @@ namespace MediaConch
     //---------------------------------------------------------------------------
     bool WebCommonPage::report_is_html(const QString& report)
     {
-        QRegExp reg("^(<\\!DOCTYPE.*html|<html>.*</html>$)", Qt::CaseInsensitive);
+        QRegularExpression reg("^(<\\!DOCTYPE.*html|<html>.*</html>$)", QRegularExpression::CaseInsensitiveOption);
 
-        if (reg.indexIn(report.trimmed(), 0) != -1)
-            return true;
-
-        return false;
+        return reg.match(report.trimmed()).hasMatch();
     }
 
     //---------------------------------------------------------------------------
     bool WebCommonPage::report_is_xml(const QString& report)
     {
-        QRegExp reg("<\\?xml ", Qt::CaseInsensitive);
+        QRegularExpression reg("<\\?xml ", QRegularExpression::CaseInsensitiveOption);
 
-        if (reg.indexIn(report, 0) != -1)
-            return true;
-
-        return false;
+        return reg.match(report).hasMatch();
     }
 
     //---------------------------------------------------------------------------
     bool WebCommonPage::report_is_json(const QString& report)
     {
-        QRegExp reg("^\\{.*\\}$", Qt::CaseInsensitive);
+        QRegularExpression reg("^\\{.*\\}$", QRegularExpression::CaseInsensitiveOption);
 
-        if (reg.indexIn(report.trimmed(), 0) != -1)
-            return true;
-
-        return false;
+        return reg.match(report.trimmed()).hasMatch();
     }
 
     QString WebCommonPage::get_file_tool(const QString& file)
@@ -1088,6 +1089,53 @@ namespace MediaConch
         else
             rule_data += ",\"ope\":\"\"";
 
+        if (r->source)
+        {
+            rule_data += ",\"source\":{";
+
+            len = r->source->track_type.length();
+            if (len > 0)
+            {
+                QString source_tracktype = QString().fromUtf8(r->source->track_type.c_str(), r->source->track_type.length());
+                string_to_json(source_tracktype);
+                rule_data += QString("\"tracktype\":\"%1\"").arg(source_tracktype);
+            }
+            else
+                rule_data += "\"tracktype\":\"\"";
+
+            len = r->source->field.length();
+            if (len > 0)
+            {
+                QString source_field = QString().fromUtf8(r->source->field.c_str(), r->source->field.length());
+                string_to_json(source_field);
+                rule_data += QString(",\"field\":\"%1\"").arg(source_field);
+            }
+            else
+                rule_data += ",\"field\":\"\"";
+
+            len = r->source->occurrence.length();
+            if (len > 0)
+            {
+                QString source_occurrence = QString().fromUtf8(r->source->occurrence.c_str(), r->source->occurrence.length());
+                string_to_json(source_occurrence);
+                rule_data += QString(",\"occurrence\":\"%1\"").arg(source_occurrence);
+            }
+            else
+                rule_data += ",\"occurrence\":\"\"";
+
+            len = r->source->scope.length();
+            if (len > 0)
+            {
+                QString source_scope = QString().fromUtf8(r->source->scope.c_str(), r->source->scope.length());
+                string_to_json(source_scope);
+                rule_data += QString(",\"scope\":\"%1\"").arg(source_scope);
+            }
+            else
+                rule_data += ",\"scope\":\"\"";
+
+            rule_data += "}";
+        }
+
         len = r->value.length();
         if (len > 0)
         {
@@ -1521,7 +1569,9 @@ namespace MediaConch
         return json;
     }
 
-    QString WebCommonPage::xslt_policy_rule_edit(int rule_id, int policy_id, const QString& title, const QString& type, const QString& field, const QString& occurrence, const QString& ope, const QString& value, const QString& scope, const QString& level)
+    QString WebCommonPage::xslt_policy_rule_edit(int rule_id, int policy_id, const QString& title, const QString& type,
+                                                 const QString& field, const QString& occurrence, const QString& ope,
+                                                 const QString& value, const QString& scope, const QString& level)
     {
         QString err;
         QString json;
@@ -1561,6 +1611,54 @@ namespace MediaConch
         return json;
     }
 
+    QString WebCommonPage::xslt_policy_rule_edit(int rule_id, int policy_id, const QString &title, const QString &type,
+                                                             const QString &field, const QString &occurrence, const QString &ope,
+                                                             const QJsonObject& source, const QString &scope, const QString &level)
+    {
+        QString err;
+        QString json;
+
+        XsltPolicyRule rule;
+        rule.source = new XsltPolicyRule::Source;
+
+        rule.node_name     = title.toUtf8().data();
+        rule.ope           = ope.toUtf8().data();
+        rule.track_type    = type.toUtf8().data();
+        rule.field         = field.toUtf8().data();
+        rule.occurrence    = occurrence.toUtf8().data();
+        rule.scope         = scope.toUtf8().data();
+        rule.level         = level.toUtf8().data();
+
+        rule.source->track_type = source.value("tracktype").toString().toUtf8().data();
+        rule.source->field      = source.value("field").toString().toUtf8().data();
+        rule.source->occurrence = source.value("occurrence").toString().toUtf8().data();
+        rule.source->scope      = source.value("scope").toString().toUtf8().data();
+
+        int code;
+        if ((code = mainwindow->xslt_policy_rule_edit(policy_id, rule_id, &rule, err)) < 0)
+        {
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
+            return json;
+        }
+
+        mainwindow->policy_save(policy_id, err);
+
+        XsltPolicyRule* r = mainwindow->xslt_policy_rule_get(policy_id, rule_id, err);
+        if (!r)
+        {
+            json = "{\"error\":\"Cannot get the policy rule edited\"}";
+            return json;
+        }
+
+        QString rule_data;
+        create_rule_tree(r, rule_data);
+        json = QString("{\"rule\":");
+        json += rule_data;
+        json += "}";
+        return json;
+    }
+
     QString WebCommonPage::xslt_policy_rule_duplicate(int policy_id, int rule_id, int dst_policy_id)
     {
         //return: rule
