@@ -13,6 +13,7 @@
 #include <QMap>
 #include <QString>
 #include <QStringList>
+#include <QJsonObject>
 #include <QFileInfo>
 
 #if defined(WEB_MACHINE_KIT)
@@ -77,10 +78,7 @@ public Q_SLOTS:
                                              const QString& verbosity, bool fixer, const QStringList&);
     QString      on_file_from_db_selected();
     QString      status_reports_multi(const QStringList& ids, const QStringList& policy_ids);
-    void         on_save_settings_selected(const QString& policy, const QString& display, const QString& verbosity, const QString& parsespeed,
-                                           const QString& save_report, const QString& load_files,
-                                           const QString& save_policy, const QString& load_policy,
-                                           const QString& save_display, const QString& load_display);
+    void         on_save_settings_selected(const QJsonObject& values);
 
     void         menu_link_checker(const QString& name);
     void         on_input_changed(const QString& inputName);
@@ -136,7 +134,12 @@ public Q_SLOTS:
     QString      policy_edit(int id, const QString& name, const QString& description, const QStringList& tags,
                              const QString& license, const QString& type, const QString& level, const QString& visibility);
     QString      xslt_policy_rule_create(int policy_id);
-    QString      xslt_policy_rule_edit(int rule_id, int policy_id, const QString& title, const QString& type, const QString& field, const QString& occurrence, const QString& ope, const QString& value, const QString& scope, const QString& level);
+    QString      xslt_policy_rule_edit(int rule_id, int policy_id, const QString& title, const QString& type,
+                                       const QString& field, const QString& occurrence, const QString& ope,
+                                       const QString& value, const QString& scope, const QString& level);
+    QString      xslt_policy_rule_edit(int rule_id, int policy_id, const QString& title, const QString& type,
+                                       const QString& field, const QString& occurrence, const QString& ope,
+                                       const QJsonObject& source, const QString& scope, const QString& level);
     QString      xslt_policy_rule_duplicate(int policy_id, int rule_id, int dst_policy_id);
     QString      xslt_policy_rule_move(int policy_id, int rule_id, int dst_policy_id);
     QString      xslt_policy_rule_delete(int policy_id, int rule_id);
